@@ -1,6 +1,19 @@
-# file MASS/qda.q
+# file MASS/R/qda.R
 # copyright (C) 1994-2006 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 qda <- function(x, ...) UseMethod("qda")
 
 qda.formula <- function(formula, data, ..., subset, na.action)
@@ -64,9 +77,12 @@ qda.default <-
 {
     if(is.null(dim(x))) stop("'x' is not a matrix")
     x <- as.matrix(x)
+    if(any(!is.finite(x)))
+        stop("infinite, NA or NaN values in 'x'")
     n <- nrow(x)
     p <- ncol(x)
-    if(n != length(grouping)) stop("nrow(x) and length(grouping) are different")
+    if(n != length(grouping))
+        stop("nrow(x) and length(grouping) are different")
     g <- as.factor(grouping)
     lev <- levels(g)
     counts <- as.vector(table(g))
@@ -282,7 +298,7 @@ print.qda <- function(x, ...)
     if(!is.null(cl <- x$call)) {
         names(cl)[2] <- ""
         cat("Call:\n")
-        dput(cl)
+        dput(cl, control=NULL)
     }
     cat("\nPrior probabilities of groups:\n")
     print(x$prior, ...)
